@@ -4,7 +4,6 @@ import redis
 import json
 import threading
 from flyt_python.utils import add_to_job_requests, get_data
-
 host = 'localhost'
 port = 6379
 db_i = 0
@@ -27,10 +26,10 @@ class DroneApiConnector():
         Get namespace and make a websocket connection with the drone
         :param token: Personal Access Token assigned to the User (Flytbase Platform)
         :param vehicle_id: Vehicle ID assigned to the drone (Flytbase Platform)
-        :param ip_address: Drone's IPv4 Address
+        :param ip_address: 'localhost' for flytsim docker and 'cloud' for actual drone
         :param timeout: Subscription time in seconds
-        :param time_constant: Data storage time in seconds
-        :param conn_time: after this much time of inactivity the websocket connection closes
+        :param time_constant: Data storage time for redis in seconds
+        :param conn_time: after this much time of inactivity the websocket connection closes, -1 for forever
         :param wait_for_drone_response: True/False
         """
         if len(token) != 40 or len(vehicle_id) != 8:
@@ -39,6 +38,7 @@ class DroneApiConnector():
         self.timeout = timeout
         self.headers = dict(Authorization='Token ' + token, VehicleID=vehicle_id)
 
+
         try:
             result = requests.get(url, headers=self.headers)
             if (result.status_code == 200):
@@ -116,7 +116,7 @@ class DroneApiConnector():
         Land vehicle at current position. Check API usage section below before using this API.
         :param async: If true, asynchronous mode is set
         :return: {"success": True/False, "message": "debug message"}
-        """        #self.takeoff_response()
+        """
         if not self.activated:
             return "WAIT FOR DRONE" + self.namespace + " TO ACTIVATE"
         request = dict(op="call_service", service="/" + self.namespace + "/navigation/land", type="core_api/Land",
@@ -390,6 +390,19 @@ class DroneApiConnector():
         return self.handle_return("/" + self.namespace + "/navigation/rtl", "on_request")
 
     # Parameter APIs
+
+    def get_adc(self):
+        """
+        Get ADC data
+        :return: {success: True/False, message: "debug message",adc_voltage: Float[2],adc_updated: Int}
+        """
+        if not self.activated:
+            return "WAIT FOR DRONE" + self.namespace + " TO ACTIVATE"
+        request = dict(op="call_service", service="/" + self.namespace + "/mavros/payload_adc",
+                       type="mavros_msgs/PayloadADC", id=self.id)
+        add_to_job_requests(request)
+        return self.handle_return("/" + self.namespace + "/mavros/payload_adc", "on_request")
+
     def set_gimbal(self, roll, pitch, yaw):
         """
         This API sends gimbal attitude setpoint command to the autopilot via
@@ -406,6 +419,20 @@ class DroneApiConnector():
         add_to_job_requests(request)
         return self.handle_return("/" + self.namespace + "/payload/gimbal_set", "on_request")
 
+    def create_params(self, param_id, param_value):
+        """
+        This API creates a new parameter.
+        :param param_id: Name of the parameter
+        :param param_value: Value of the parameter
+        :return: {"success": True/False, "message": "debug message"}
+        """
+        if not self.activated:
+            return "WAIT FOR DRONE" + self.namespace + " TO ACTIVATE"
+        request = dict(op="call_service", service="/" + self.namespace + "/param/param_create",
+                       type="core_api/ParamCreate", id=self.id, args=dict(param_id=param_id, param_info=param_value))
+        add_to_job_requests(request)
+        return self.handle_return("/" + self.namespace + "/param/param_create", "on_request")
+
     def set_params(self, param_id, param_value):
         """
         This API sets the value of a desired parameter
